#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define service product_converter

Name:           obs-service-%service
Version:        1.5.6
Release:        1.5
Summary:        An OBS source service: create product media build descriptions
License:        GPL-2.0-or-later
Group:          Development/Tools/Building
URL:            https://github.com/openSUSE/obs-service-%{service}
Source:         %name-%{version}.tar.xz
BuildArch:      noarch
BuildRequires:  perl(XML::Structured)
Requires:       perl(XML::Structured)
# temp workaround for broken provides of obs-server
BuildRequires:  perl-XML-Structured
Requires:       perl-XML-Structured
# workaround for missing requires of perl-XML-structured
BuildRequires:  perl-XML-Parser
Requires:       perl-XML-Parser

%description
Use this product converter to create product builds for openSUSE Tumbleweed or
SLE 15.

%prep
%setup -q

%build

%install
mkdir -p %buildroot%{_prefix}/lib/obs/service
install -m 0644 *.pm product_converter.service \
   %buildroot%{_prefix}/lib/obs/service
install -m 0755 create_single_product product_converter \
   %buildroot%{_prefix}/lib/obs/service

%check
# minimal test
rm -rf test/outdir
mkdir -p test/outdir
cd test/simple_product
PERL5LIB=%buildroot%{_prefix}/lib/obs/service ../../product_converter --outdir $PWD/../outdir/ || exit 1
cd ../outdir/
for file in _multibuild  simple-cd-cd-i586_x86_64.kiwi  simple-cd-cd-i586_x86_64.kwd  simple-release.spec
do
  if [ ! -e "$file" ]; then
    echo "ERROR $file missing"
    exit 1
  fi
done

%files
%dir %{_prefix}/lib/obs
%license COPYING
%{_prefix}/lib/obs/service

%changelog
* Fri Aug 11 2023 Adrian Schröter <adrian@suse.de>
- 1.5.6
  * create BcntSyncTag comments by default
* Thu Jul 27 2023 Adrian Schröter <adrian@suse.de>
- 1.5.5
  * Add download_mirror_policy_option, opt-out option, used
    by default in product-builder
* Wed Feb  8 2023 Adrian Schröter <adrian@suse.de>
- 1.5.4
  * make purl_distro of SPDX data configurable
* Tue Oct 11 2022 Adrian Schröter <adrian@suse.de>
- 1.5.3
  * fixed encoding of product provides
  * revert fix use_undecided="true" special case
* Wed Nov 10 2021 Adrian Schröter <adrian@suse.de>
- 1.5.2
  * transport module informations
  * allow to specify a DVD volume ID manual
* Fri Sep 24 2021 Adrian Schröter <adrian@suse.de>
- 1.5.0
  * support run_depenendency_check="warn" or ="error"
* Wed Sep 22 2021 Adrian Schröter <adrian@suse.de>
- 1.4.9
  * fix use_undecided="true" special case
* Wed Sep  8 2021 Adrian Schröter <adrian@suse.de>
- 1.4.8
  * removing another trace of obsolete SP migration package handling
* Tue Aug 24 2021 Adrian Schröter <adrian@suse.de>
- 1.4.7
  * new option for picking rpms by version number instead of
    repository priority
* Wed Jun 30 2021 Adrian Schröter <adrian@suse.de>
- 1.4.6
  * add a field for build.opensuse.org default repository name for
    zypper (bsc#1187425)
  * add an automatic field for default OBS download URL
  * release spec file cleanup
* Thu Nov 12 2020 Adrian Schröter <adrian@suse.de>
- 1.4.5
  * Write beta version to the pretty name of os-release file.
  * drop it from VERSION_ID since space violate the format spec.
    jsc#SLE-170001
* Wed Sep 30 2020 Adrian Schröter <adrian@suse.de>
- 1.4.4
  - allow to write milestone comment independent of beta version (OBS-51)
  - additional warning when using it manually to verify OBS_NAME
* Tue Jul 28 2020 Adrian Schröter <adrian@suse.de>
- 1.4.2
  - try to get OBS_NAME when using evil local wrapper scripts
    which do not set it (they can still set it wrong)
  - add warning for missing OBS_NAME
* Mon Jul 20 2020 Adrian Schröter <adrian@suse.de>
- 1.4.1
  - fix regression creating empty ExclusiveArchs lists
* Tue Jun 23 2020 Adrian Schröter <adrian@suse.de>
- 1.4.0
  - obsolete and conflict predecessor flavors
  - Avoid Duplicate Repository Entries in .prod file
  - If defined build a ExclusiveArch list from 'distrotarget'
* Mon Oct 14 2019 Adrian Schröter <adrian@suse.de>
- 1.3.0
  - no more migration spec files got created (supposed to be obsolete)
  - extend summary: with possible defined beta version
* Wed Jan 30 2019 Adrian Schröter <adrian@suse.de>
- 1.2.0
  * provide and require correct obsproduct:/ for pool repository
* Mon Oct 15 2018 Adrian Schröter <adrian@suse.de>
- 1.1.5
  * enable preference hybrid flag in RPi mode
* Mon Aug 27 2018 Adrian Schröter <adrian@suse.de>
- 1.1.4
  * regression fix by Ludwig for release package handling
* Fri Aug 24 2018 Adrian Schröter <adrian@suse.de>
- update to 1.1.3
  * support RPI hybrid mode
* Wed Feb  7 2018 adrian@suse.de
- update to 1.1.2
  * skip repos which only provide a URL for installed prod file
* Thu Feb  1 2018 adrian@suse.de
- update to 1.1.1
  * support listig of pool repositories in sle mode for installed
    .prod files. (FATE#323664)
  * drop all old code pathes before Leap 15 / SLE 15
* Thu Oct 12 2017 coolo@suse.com
- escape literal { in regexp
* Thu Oct 12 2017 coolo@suse.com
- fix perl path for %%check
* Thu Oct  5 2017 adrian@suse.de
- seperate -> seperate option rename
* Mon Oct  2 2017 adrian@suse.de
- add ID_LIKE to /etc/os-release (bsc#1058465)
* Fri Sep 22 2017 adrian@suse.de
- seperate media are an explicit setting now
- fixed GPL license file
* Wed Aug  9 2017 adrian@suse.de
- allow user to predefine _multibuild file
* Tue Jun 20 2017 adrian@suse.de
- minor cleanup
* Thu Mar 16 2017 adrian@suse.de
- add test case
* Mon Feb 13 2017 adrian@suse.de
- initial version
